/**
 * oscP5sendreceive by andreas schlegel
 * example shows how to send and receive osc messages.
 * oscP5 website at http://www.sojamo.de/oscP5
 */
 
import oscP5.*;

import netP5.*;

import processing.sound.*;
  
OscP5 oscP5;
NetAddress myRemoteLocation;

AudioIn input1;
Amplitude rms1;

float volumeGeneral1;

boolean isStrobing, isSunstrip;

float x, y;
float rayon1, rayonCible1;

float vol;

void setup() {
  size(400,400);
  frameRate(25);
  /* start oscP5, listening for incoming messages at port 1000 */
  oscP5 = new OscP5(this,1000);
  
  myRemoteLocation = new NetAddress("192.168.65.1",12000);
  
  initSon();
 
    x = width/2;
    y = height/2;
    
}

void initSon() {
  
  input1 = new AudioIn(this, 0);
  input1.start();
  rms1 = new Amplitude(this);
  rms1.input(input1);
  
}


void draw() {
  background(0);  
  
  noStroke();
  fill(255,0,0,10);
  rect(0,0,width,height);

  fill(0,255,0);
  ellipse(x, y, rayon1, rayon1);

  grossir();
  
}

void grossir() {

    input1.amp(map(mouseY, 0, height, 0.0, 10.0));
    volumeGeneral1 = int(map(rms1.analyze(), 0, 0.5, 1, 350));
    
    rayonCible1 = volumeGeneral1;
    rayon1 += (rayonCible1-rayon1)*.5;
    
    if (rayon1 <= 10) vol = 0;
    else vol = int(map(rayonCible1, 10, 350, 0, 255));

    OscMessage myMessage = new OscMessage("/1/volume");
  
   myMessage.add(vol); /* add an int to the osc message */

  /* send the message */
   oscP5.send(myMessage, myRemoteLocation); 
   
  // println(volumeGeneral1);

}


float lightAmount;

float direction = .001;

void sunStrip() {
  
   OscMessage myMessage = new OscMessage("/2/fader2");
   myMessage.add(lightAmount);
   oscP5.send(myMessage, myRemoteLocation); 
  
  lightAmount += direction;
  if (lightAmount > 255 || lightAmount < 0) {
    direction = -direction;
  }
  
}



void mousePressed() {
  /* in the following different ways of creating osc messages are shown by example */
  //OscMessage myMessage = new OscMessage("/1/fader1");
  
  //myMessage.add(lightRed); /* add an int to the osc message */
  isStrobing = !isStrobing;

}


void keyPressed() {
  
  isSunstrip = !isSunstrip;
  
}


/* incoming osc message are forwarded to the oscEvent method. */
void oscEvent(OscMessage theOscMessage) {
  /* print the address pattern and the typetag of the received OscMessage */
  print("### received an osc message.");
  print(" addrpattern: "+theOscMessage.addrPattern());
  println(" typetag: "+theOscMessage.typetag());
}